==> silc-client-0.7.2.tar.gz: silc-client-0.7.2/acconfig.h <==
/* Name of the package. */
#undef PACKAGE

/* Version of the package. */
#undef VERSION

/* Debugging */
#undef SILC_DEBUG

/* Default configuration file */
#undef SILC_SERVER_CONFIG_FILE

/* Multi-thread support */
#undef SILC_THREADS
#undef SILC_HAVE_PTHREAD

/* IPv6 support */
#undef HAVE_IPV6

/* Default paths */
#undef SILC_ETCDIR
#undef SILC_HELPDIR
#undef SILC_DOCDIR
#undef SILC_MODULESDIR
#undef SILC_LOGSDIR

/* SIM (SILC Module) support */
#undef SILC_SIM
#undef HAVE_RTLD_NOW
#undef HAVE_RTLD_LAZY

/* Types */
#undef SILC_SIZEOF_LONG_LONG
#undef SILC_SIZEOF_LONG
#undef SILC_SIZEOF_INT
#undef SILC_SIZEOF_SHORT
#undef SILC_SIZEOF_CHAR
#undef SILC_SIZEOF_VOID_P

/* MP library */
#undef SILC_MP_GMP
#undef SILC_MP_NSS_MPI

/* Redefs for SOCKS5 library */
/* macros/curses checks */
#undef HAS_CURSES
#undef USE_SUNOS_CURSES
#undef USE_BSD_CURSES
#undef USE_SYSV_CURSES
#undef USE_NCURSES
#undef NO_COLOR_CURSES
#undef SCO_FLAVOR

#undef SOCKS
#undef SOCKS5
#undef Rconnect
#undef Rgetsockname
#undef Rgetpeername
#undef Rbind
#undef Raccept  
#undef Rlisten
#undef Rselect
#undef Rrecvfrom
#undef Rsendto
#undef Rrecv
#undef Rsend
#undef Rread
#undef Rwrite
#undef Rrresvport
#undef Rshutdown
#undef Rlisten
#undef Rclose
#undef Rdup
#undef Rdup2
#undef Rfclose
#undef Rgethostbyname

/* Native WIN32 compilation (-mno-cygwin GCC option) under cygwin, though
   the code compiles with any native WIN32 compiler. */
#undef SILC_WIN32

/* SILC distribution definitions (leave this at the end of file) */
#undef SILC_DIST_TOOLKIT
#undef SILC_DIST_CLIENT
#undef SILC_DIST_SERVER
#undef SILC_DIST_WIN32DLL

==> silc-client-1.0.2.tar.gz: silc-client-1.0.2/acconfig.h <==
/* Name of the package. */
#undef PACKAGE

/* Version of the package. */
#undef VERSION

/* Default configuration file */
#undef SILC_SERVER_CONFIG_FILE

/* Multi-thread support */
#undef SILC_THREADS

/* These can be defined only on other than Win32 systems */
#ifndef SILC_WIN32

/* Debugging */
#undef SILC_DEBUG
#undef SILC_STACKTRACE

/* Multi-thread support */
#undef SILC_HAVE_PTHREAD

/* IPv6 Support */
#undef HAVE_IPV6

#endif /* SILC_WIN32 */

/* Default paths */
#undef SILC_ETCDIR
#undef SILC_HELPDIR
#undef SILC_DOCDIR
#undef SILC_MODULESDIR
#undef SILC_LOGSDIR

/* SIM (SILC Module) support */
#undef SILC_SIM
#undef HAVE_RTLD_NOW
#undef HAVE_RTLD_LAZY

/* MP library */
#undef SILC_MP_GMP
#undef SILC_MP_NSS_MPI

/* contrib library functions */
#undef HAVE_REGEX
#undef HAVE_GETOPT_LONG

/* macros/curses checks */
#undef HAS_CURSES
#undef USE_SUNOS_CURSES
#undef USE_BSD_CURSES
#undef USE_SYSV_CURSES
#undef USE_NCURSES
#undef NO_COLOR_CURSES
#undef SCO_FLAVOR

/* Redefs for SOCKS5 library */
#undef SOCKS
#undef SOCKS5
#undef Rconnect
#undef Rgetsockname
#undef Rgetpeername
#undef Rbind
#undef Raccept  
#undef Rlisten
#undef Rselect
#undef Rrecvfrom
#undef Rsendto
#undef Rrecv
#undef Rsend
#undef Rread
#undef Rwrite
#undef Rrresvport
#undef Rshutdown
#undef Rlisten
#undef Rclose
#undef Rdup
#undef Rdup2
#undef Rfclose
#undef Rgethostbyname

/* Native WIN32 compilation (-mno-cygwin GCC option) under cygwin, though
   the code compiles with any native WIN32 compiler. */
#undef SILC_WIN32

/* SILC distribution definitions (leave this at the end of file) */
#undef SILC_DIST_TOOLKIT
#undef SILC_DIST_CLIENT
#undef SILC_DIST_SERVER
#undef SILC_DIST_WIN32DLL
